==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class JVMChaosSpecFluent<A extends JVMChaosSpecFluent<A>> extends BaseFluent<A>{
  public JVMChaosSpecFluent() {
  }
  
  public JVMChaosSpecFluent(JVMChaosSpec instance) {
    this.copyInstance(instance);
  }
  private String action;
  private String className;
  private List<String> containerNames = new ArrayList<String>();
  private Integer cpuCount;
  private String duration;
  private String exception;
  private Integer latency;
  private String memType;
  private String method;
  private String mode;
  private String name;
  private Integer port;
  private String ruleData;
  private PodSelectorSpecBuilder selector;
  private String value;
  
  protected void copyInstance(JVMChaosSpec instance) {
    instance = (instance != null ? instance : new JVMChaosSpec());
    if (instance != null) {
          this.withAction(instance.getAction());
          this.withClassName(instance.getClassName());
          this.withContainerNames(instance.getContainerNames());
          this.withCpuCount(instance.getCpuCount());
          this.withDuration(instance.getDuration());
          this.withException(instance.getException());
          this.withLatency(instance.getLatency());
          this.withMemType(instance.getMemType());
          this.withMethod(instance.getMethod());
          this.withMode(instance.getMode());
          this.withName(instance.getName());
          this.withPort(instance.getPort());
          this.withRuleData(instance.getRuleData());
          this.withSelector(instance.getSelector());
          this.withValue(instance.getValue());
          this.withAction(instance.getAction());
          this.withClassName(instance.getClassName());
          this.withContainerNames(instance.getContainerNames());
          this.withCpuCount(instance.getCpuCount());
          this.withDuration(instance.getDuration());
          this.withException(instance.getException());
          this.withLatency(instance.getLatency());
          this.withMemType(instance.getMemType());
          this.withMethod(instance.getMethod());
          this.withMode(instance.getMode());
          this.withName(instance.getName());
          this.withPort(instance.getPort());
          this.withRuleData(instance.getRuleData());
          this.withSelector(instance.getSelector());
          this.withValue(instance.getValue());
        }
  }
  
  public String getAction() {
    return this.action;
  }
  
  public A withAction(String action) {
    this.action = action;
    return (A) this;
  }
  
  public boolean hasAction() {
    return this.action != null;
  }
  
  public String getClassName() {
    return this.className;
  }
  
  public A withClassName(String className) {
    this.className = className;
    return (A) this;
  }
  
  public boolean hasClassName() {
    return this.className != null;
  }
  
  public A addToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.add(index, item);
    return (A)this;
  }
  
  public A setToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.set(index, item); return (A)this;
  }
  
  public A addToContainerNames(java.lang.String... items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  
  public A addAllToContainerNames(Collection<String> items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  
  public A removeFromContainerNames(java.lang.String... items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  
  public A removeAllFromContainerNames(Collection<String> items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  
  public List<String> getContainerNames() {
    return this.containerNames;
  }
  
  public String getContainerName(int index) {
    return this.containerNames.get(index);
  }
  
  public String getFirstContainerName() {
    return this.containerNames.get(0);
  }
  
  public String getLastContainerName() {
    return this.containerNames.get(containerNames.size() - 1);
  }
  
  public String getMatchingContainerName(Predicate<String> predicate) {
      for (String item : containerNames) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingContainerName(Predicate<String> predicate) {
      for (String item : containerNames) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withContainerNames(List<String> containerNames) {
    if (containerNames != null) {
        this.containerNames = new ArrayList();
        for (String item : containerNames) {
          this.addToContainerNames(item);
        }
    } else {
      this.containerNames = null;
    }
    return (A) this;
  }
  
  public A withContainerNames(java.lang.String... containerNames) {
    if (this.containerNames != null) {this.containerNames.clear(); _visitables.remove("containerNames"); }
    if (containerNames != null) {for (String item :containerNames){ this.addToContainerNames(item);}} return (A) this;
  }
  
  public boolean hasContainerNames() {
    return this.containerNames != null && !this.containerNames.isEmpty();
  }
  
  public Integer getCpuCount() {
    return this.cpuCount;
  }
  
  public A withCpuCount(Integer cpuCount) {
    this.cpuCount = cpuCount;
    return (A) this;
  }
  
  public boolean hasCpuCount() {
    return this.cpuCount != null;
  }
  
  public String getDuration() {
    return this.duration;
  }
  
  public A withDuration(String duration) {
    this.duration = duration;
    return (A) this;
  }
  
  public boolean hasDuration() {
    return this.duration != null;
  }
  
  public String getException() {
    return this.exception;
  }
  
  public A withException(String exception) {
    this.exception = exception;
    return (A) this;
  }
  
  public boolean hasException() {
    return this.exception != null;
  }
  
  public Integer getLatency() {
    return this.latency;
  }
  
  public A withLatency(Integer latency) {
    this.latency = latency;
    return (A) this;
  }
  
  public boolean hasLatency() {
    return this.latency != null;
  }
  
  public String getMemType() {
    return this.memType;
  }
  
  public A withMemType(String memType) {
    this.memType = memType;
    return (A) this;
  }
  
  public boolean hasMemType() {
    return this.memType != null;
  }
  
  public String getMethod() {
    return this.method;
  }
  
  public A withMethod(String method) {
    this.method = method;
    return (A) this;
  }
  
  public boolean hasMethod() {
    return this.method != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode = mode;
    return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port = port;
    return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public String getRuleData() {
    return this.ruleData;
  }
  
  public A withRuleData(String ruleData) {
    this.ruleData = ruleData;
    return (A) this;
  }
  
  public boolean hasRuleData() {
    return this.ruleData != null;
  }
  
  public PodSelectorSpec buildSelector() {
    return this.selector != null ? this.selector.build() : null;
  }
  
  public A withSelector(PodSelectorSpec selector) {
    this._visitables.remove(this.selector);
    if (selector != null) {
        this.selector = new PodSelectorSpecBuilder(selector);
        this._visitables.get("selector").add(this.selector);
    } else {
        this.selector = null;
        this._visitables.get("selector").remove(this.selector);
    }
    return (A) this;
  }
  
  public boolean hasSelector() {
    return this.selector != null;
  }
  
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  
  public SelectorNested<A> withNewSelectorLike(PodSelectorSpec item) {
    return new SelectorNested(item);
  }
  
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodSelectorSpecBuilder().build()));
  }
  
  public SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value = value;
    return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMChaosSpecFluent that = (JVMChaosSpecFluent) o;
    if (!java.util.Objects.equals(action, that.action)) return false;
    if (!java.util.Objects.equals(className, that.className)) return false;
    if (!java.util.Objects.equals(containerNames, that.containerNames)) return false;
    if (!java.util.Objects.equals(cpuCount, that.cpuCount)) return false;
    if (!java.util.Objects.equals(duration, that.duration)) return false;
    if (!java.util.Objects.equals(exception, that.exception)) return false;
    if (!java.util.Objects.equals(latency, that.latency)) return false;
    if (!java.util.Objects.equals(memType, that.memType)) return false;
    if (!java.util.Objects.equals(method, that.method)) return false;
    if (!java.util.Objects.equals(mode, that.mode)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(port, that.port)) return false;
    if (!java.util.Objects.equals(ruleData, that.ruleData)) return false;
    if (!java.util.Objects.equals(selector, that.selector)) return false;
    if (!java.util.Objects.equals(value, that.value)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(action,  className,  containerNames,  cpuCount,  duration,  exception,  latency,  memType,  method,  mode,  name,  port,  ruleData,  selector,  value,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (className != null) { sb.append("className:"); sb.append(className + ","); }
    if (containerNames != null && !containerNames.isEmpty()) { sb.append("containerNames:"); sb.append(containerNames + ","); }
    if (cpuCount != null) { sb.append("cpuCount:"); sb.append(cpuCount + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (exception != null) { sb.append("exception:"); sb.append(exception + ","); }
    if (latency != null) { sb.append("latency:"); sb.append(latency + ","); }
    if (memType != null) { sb.append("memType:"); sb.append(memType + ","); }
    if (method != null) { sb.append("method:"); sb.append(method + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (ruleData != null) { sb.append("ruleData:"); sb.append(ruleData + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  public class SelectorNested<N> extends PodSelectorSpecFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodSelectorSpec item) {
      this.builder = new PodSelectorSpecBuilder(this, item);
    }
    PodSelectorSpecBuilder builder;
    
    public N and() {
      return (N) JVMChaosSpecFluent.this.withSelector(builder.build());
    }
    
    public N endSelector() {
      return and();
    }
    
  
  }

}

==> chaosmesh-model-7.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class JVMChaosSpecFluent<A extends JVMChaosSpecFluent<A>> extends BaseFluent<A>{
  public JVMChaosSpecFluent() {
  }
  
  public JVMChaosSpecFluent(JVMChaosSpec instance) {
    this.copyInstance(instance);
  }
  private String action;
  private String className;
  private List<String> containerNames = new ArrayList<String>();
  private Integer cpuCount;
  private String database;
  private String duration;
  private String exception;
  private Integer latency;
  private String memType;
  private String method;
  private String mode;
  private String mysqlConnectorVersion;
  private String name;
  private Integer pid;
  private Integer port;
  private String remoteCluster;
  private String returnValue;
  private String ruleData;
  private PodSelectorSpecBuilder selector;
  private String sqlType;
  private String table;
  private String value;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(JVMChaosSpec instance) {
    instance = (instance != null ? instance : new JVMChaosSpec());
    if (instance != null) {
          this.withAction(instance.getAction());
          this.withClassName(instance.getClassName());
          this.withContainerNames(instance.getContainerNames());
          this.withCpuCount(instance.getCpuCount());
          this.withDatabase(instance.getDatabase());
          this.withDuration(instance.getDuration());
          this.withException(instance.getException());
          this.withLatency(instance.getLatency());
          this.withMemType(instance.getMemType());
          this.withMethod(instance.getMethod());
          this.withMode(instance.getMode());
          this.withMysqlConnectorVersion(instance.getMysqlConnectorVersion());
          this.withName(instance.getName());
          this.withPid(instance.getPid());
          this.withPort(instance.getPort());
          this.withRemoteCluster(instance.getRemoteCluster());
          this.withReturnValue(instance.getReturnValue());
          this.withRuleData(instance.getRuleData());
          this.withSelector(instance.getSelector());
          this.withSqlType(instance.getSqlType());
          this.withTable(instance.getTable());
          this.withValue(instance.getValue());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getAction() {
    return this.action;
  }
  
  public A withAction(String action) {
    this.action = action;
    return (A) this;
  }
  
  public boolean hasAction() {
    return this.action != null;
  }
  
  public String getClassName() {
    return this.className;
  }
  
  public A withClassName(String className) {
    this.className = className;
    return (A) this;
  }
  
  public boolean hasClassName() {
    return this.className != null;
  }
  
  public A addToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.add(index, item);
    return (A)this;
  }
  
  public A setToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.set(index, item); return (A)this;
  }
  
  public A addToContainerNames(java.lang.String... items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  
  public A addAllToContainerNames(Collection<String> items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  
  public A removeFromContainerNames(java.lang.String... items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  
  public A removeAllFromContainerNames(Collection<String> items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  
  public List<String> getContainerNames() {
    return this.containerNames;
  }
  
  public String getContainerName(int index) {
    return this.containerNames.get(index);
  }
  
  public String getFirstContainerName() {
    return this.containerNames.get(0);
  }
  
  public String getLastContainerName() {
    return this.containerNames.get(containerNames.size() - 1);
  }
  
  public String getMatchingContainerName(Predicate<String> predicate) {
      for (String item : containerNames) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingContainerName(Predicate<String> predicate) {
      for (String item : containerNames) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withContainerNames(List<String> containerNames) {
    if (containerNames != null) {
        this.containerNames = new ArrayList();
        for (String item : containerNames) {
          this.addToContainerNames(item);
        }
    } else {
      this.containerNames = null;
    }
    return (A) this;
  }
  
  public A withContainerNames(java.lang.String... containerNames) {
    if (this.containerNames != null) {
        this.containerNames.clear();
        _visitables.remove("containerNames");
    }
    if (containerNames != null) {
      for (String item : containerNames) {
        this.addToContainerNames(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasContainerNames() {
    return this.containerNames != null && !this.containerNames.isEmpty();
  }
  
  public Integer getCpuCount() {
    return this.cpuCount;
  }
  
  public A withCpuCount(Integer cpuCount) {
    this.cpuCount = cpuCount;
    return (A) this;
  }
  
  public boolean hasCpuCount() {
    return this.cpuCount != null;
  }
  
  public String getDatabase() {
    return this.database;
  }
  
  public A withDatabase(String database) {
    this.database = database;
    return (A) this;
  }
  
  public boolean hasDatabase() {
    return this.database != null;
  }
  
  public String getDuration() {
    return this.duration;
  }
  
  public A withDuration(String duration) {
    this.duration = duration;
    return (A) this;
  }
  
  public boolean hasDuration() {
    return this.duration != null;
  }
  
  public String getException() {
    return this.exception;
  }
  
  public A withException(String exception) {
    this.exception = exception;
    return (A) this;
  }
  
  public boolean hasException() {
    return this.exception != null;
  }
  
  public Integer getLatency() {
    return this.latency;
  }
  
  public A withLatency(Integer latency) {
    this.latency = latency;
    return (A) this;
  }
  
  public boolean hasLatency() {
    return this.latency != null;
  }
  
  public String getMemType() {
    return this.memType;
  }
  
  public A withMemType(String memType) {
    this.memType = memType;
    return (A) this;
  }
  
  public boolean hasMemType() {
    return this.memType != null;
  }
  
  public String getMethod() {
    return this.method;
  }
  
  public A withMethod(String method) {
    this.method = method;
    return (A) this;
  }
  
  public boolean hasMethod() {
    return this.method != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode = mode;
    return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public String getMysqlConnectorVersion() {
    return this.mysqlConnectorVersion;
  }
  
  public A withMysqlConnectorVersion(String mysqlConnectorVersion) {
    this.mysqlConnectorVersion = mysqlConnectorVersion;
    return (A) this;
  }
  
  public boolean hasMysqlConnectorVersion() {
    return this.mysqlConnectorVersion != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public Integer getPid() {
    return this.pid;
  }
  
  public A withPid(Integer pid) {
    this.pid = pid;
    return (A) this;
  }
  
  public boolean hasPid() {
    return this.pid != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port = port;
    return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public String getRemoteCluster() {
    return this.remoteCluster;
  }
  
  public A withRemoteCluster(String remoteCluster) {
    this.remoteCluster = remoteCluster;
    return (A) this;
  }
  
  public boolean hasRemoteCluster() {
    return this.remoteCluster != null;
  }
  
  public String getReturnValue() {
    return this.returnValue;
  }
  
  public A withReturnValue(String returnValue) {
    this.returnValue = returnValue;
    return (A) this;
  }
  
  public boolean hasReturnValue() {
    return this.returnValue != null;
  }
  
  public String getRuleData() {
    return this.ruleData;
  }
  
  public A withRuleData(String ruleData) {
    this.ruleData = ruleData;
    return (A) this;
  }
  
  public boolean hasRuleData() {
    return this.ruleData != null;
  }
  
  public PodSelectorSpec buildSelector() {
    return this.selector != null ? this.selector.build() : null;
  }
  
  public A withSelector(PodSelectorSpec selector) {
    this._visitables.remove("selector");
    if (selector != null) {
        this.selector = new PodSelectorSpecBuilder(selector);
        this._visitables.get("selector").add(this.selector);
    } else {
        this.selector = null;
        this._visitables.get("selector").remove(this.selector);
    }
    return (A) this;
  }
  
  public boolean hasSelector() {
    return this.selector != null;
  }
  
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  
  public SelectorNested<A> withNewSelectorLike(PodSelectorSpec item) {
    return new SelectorNested(item);
  }
  
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodSelectorSpecBuilder().build()));
  }
  
  public SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  
  public String getSqlType() {
    return this.sqlType;
  }
  
  public A withSqlType(String sqlType) {
    this.sqlType = sqlType;
    return (A) this;
  }
  
  public boolean hasSqlType() {
    return this.sqlType != null;
  }
  
  public String getTable() {
    return this.table;
  }
  
  public A withTable(String table) {
    this.table = table;
    return (A) this;
  }
  
  public boolean hasTable() {
    return this.table != null;
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value = value;
    return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMChaosSpecFluent that = (JVMChaosSpecFluent) o;
    if (!java.util.Objects.equals(action, that.action)) return false;
    if (!java.util.Objects.equals(className, that.className)) return false;
    if (!java.util.Objects.equals(containerNames, that.containerNames)) return false;
    if (!java.util.Objects.equals(cpuCount, that.cpuCount)) return false;
    if (!java.util.Objects.equals(database, that.database)) return false;
    if (!java.util.Objects.equals(duration, that.duration)) return false;
    if (!java.util.Objects.equals(exception, that.exception)) return false;
    if (!java.util.Objects.equals(latency, that.latency)) return false;
    if (!java.util.Objects.equals(memType, that.memType)) return false;
    if (!java.util.Objects.equals(method, that.method)) return false;
    if (!java.util.Objects.equals(mode, that.mode)) return false;
    if (!java.util.Objects.equals(mysqlConnectorVersion, that.mysqlConnectorVersion)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(pid, that.pid)) return false;
    if (!java.util.Objects.equals(port, that.port)) return false;
    if (!java.util.Objects.equals(remoteCluster, that.remoteCluster)) return false;
    if (!java.util.Objects.equals(returnValue, that.returnValue)) return false;
    if (!java.util.Objects.equals(ruleData, that.ruleData)) return false;
    if (!java.util.Objects.equals(selector, that.selector)) return false;
    if (!java.util.Objects.equals(sqlType, that.sqlType)) return false;
    if (!java.util.Objects.equals(table, that.table)) return false;
    if (!java.util.Objects.equals(value, that.value)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(action,  className,  containerNames,  cpuCount,  database,  duration,  exception,  latency,  memType,  method,  mode,  mysqlConnectorVersion,  name,  pid,  port,  remoteCluster,  returnValue,  ruleData,  selector,  sqlType,  table,  value,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (className != null) { sb.append("className:"); sb.append(className + ","); }
    if (containerNames != null && !containerNames.isEmpty()) { sb.append("containerNames:"); sb.append(containerNames + ","); }
    if (cpuCount != null) { sb.append("cpuCount:"); sb.append(cpuCount + ","); }
    if (database != null) { sb.append("database:"); sb.append(database + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (exception != null) { sb.append("exception:"); sb.append(exception + ","); }
    if (latency != null) { sb.append("latency:"); sb.append(latency + ","); }
    if (memType != null) { sb.append("memType:"); sb.append(memType + ","); }
    if (method != null) { sb.append("method:"); sb.append(method + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (mysqlConnectorVersion != null) { sb.append("mysqlConnectorVersion:"); sb.append(mysqlConnectorVersion + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (remoteCluster != null) { sb.append("remoteCluster:"); sb.append(remoteCluster + ","); }
    if (returnValue != null) { sb.append("returnValue:"); sb.append(returnValue + ","); }
    if (ruleData != null) { sb.append("ruleData:"); sb.append(ruleData + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (sqlType != null) { sb.append("sqlType:"); sb.append(sqlType + ","); }
    if (table != null) { sb.append("table:"); sb.append(table + ","); }
    if (value != null) { sb.append("value:"); sb.append(value + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class SelectorNested<N> extends PodSelectorSpecFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodSelectorSpec item) {
      this.builder = new PodSelectorSpecBuilder(this, item);
    }
    PodSelectorSpecBuilder builder;
    
    public N and() {
      return (N) JVMChaosSpecFluent.this.withSelector(builder.build());
    }
    
    public N endSelector() {
      return and();
    }
    
  
  }

}
